# coding: utf-8

"""
    zrok

    zrok client access  # noqa: E501

    OpenAPI spec version: 0.3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Overview(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_limited': 'bool',
        'environments': 'list[EnvironmentAndResources]'
    }

    attribute_map = {
        'account_limited': 'accountLimited',
        'environments': 'environments'
    }

    def __init__(self, account_limited=None, environments=None):  # noqa: E501
        """Overview - a model defined in Swagger"""  # noqa: E501
        self._account_limited = None
        self._environments = None
        self.discriminator = None
        if account_limited is not None:
            self.account_limited = account_limited
        if environments is not None:
            self.environments = environments

    @property
    def account_limited(self):
        """Gets the account_limited of this Overview.  # noqa: E501


        :return: The account_limited of this Overview.  # noqa: E501
        :rtype: bool
        """
        return self._account_limited

    @account_limited.setter
    def account_limited(self, account_limited):
        """Sets the account_limited of this Overview.


        :param account_limited: The account_limited of this Overview.  # noqa: E501
        :type: bool
        """

        self._account_limited = account_limited

    @property
    def environments(self):
        """Gets the environments of this Overview.  # noqa: E501


        :return: The environments of this Overview.  # noqa: E501
        :rtype: list[EnvironmentAndResources]
        """
        return self._environments

    @environments.setter
    def environments(self, environments):
        """Sets the environments of this Overview.


        :param environments: The environments of this Overview.  # noqa: E501
        :type: list[EnvironmentAndResources]
        """

        self._environments = environments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Overview, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Overview):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
